The Family Division is one of three divisions of the High Court. It handles complex cases involving child protection including decisions about: making a child a ‘ward of the court’, international child abduction cases, forced marriage, genital mutilation and financial relief in divorces that have been finalised in a foreign country. The Family Division hears cases in private and often anonymises the people involved to protect them.

The Family Court is different to the Family Division of the High Court. The Family Court is not part of the High Court and hears less complex cases. You can read more about the Family Division of [the High Court and the Family Court on the Judiciary website](https://www.judiciary.uk/courts-and-tribunals/family-law-courts/){target="\_blank"}.

This court began to regularly transfer judgments to The National Archives in 2022. The oldest judgment from this court included in Find Case Law is from {start_year}.

You can read more about the Family Division of [the High Court on HM Courts and Tribunals website](https://www.gov.uk/courts-tribunals/family-division-of-the-high-court){target="\_blank"}.
